@@ -4,7 +4,7 @@ package Chart::GGPlot::Backend::Plotly::Geom::Polygon;
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0011'; # VERSION
+our $VERSION = '0.0014'; # VERSION
 
 extends qw(Chart::GGPlot::Backend::Plotly::Geom::Line);
 
@@ -12,7 +12,7 @@ use PDL::Core qw(pdl);
 use Module::Load;
 
 use Chart::GGPlot::Backend::Plotly::Util qw(
-  cex_to_px to_rgb group_to_NA pdl_to_plotly
+  to_px to_rgb group_to_NA pdl_to_plotly
 );
 
 classmethod split_on () { [qw(fill color size)] }
@@ -21,7 +21,7 @@ classmethod hover_on () { 'fills' }
 around to_traces ($orig, $class : $df, $params, $plot) {
     my $traces = $class->$orig($df, $params, $plot);
     for my $trace (@$traces) {
-        my $size = cex_to_px( $df->at('size')->slice( pdl(0) ) )->at(0);
+        my $size = to_px( $df->at('size')->slice( pdl(0) ) )->at(0);
         my $fillcolor = to_rgb( $df->at('fill'), $df->at('alpha') )->at(0);
         $trace->text($df->at('hovertext')->at(0));
         $trace->line->width($size);
@@ -47,7 +47,7 @@ Chart::GGPlot::Backend::Plotly::Geom::Polygon - Chart::GGPlot's Plotly implement
 
 =head1 VERSION
 
-version 0.0011
+version 0.0014
 
 =head1 SEE ALSO
 
@@ -60,7 +60,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019-2020 by Stephan Loyd.
+This software is copyright (c) 2019-2021 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
