@@ -4,7 +4,7 @@ package Chart::GGPlot::Geom::Functions;
 
 use Chart::GGPlot::Setup;
 
-our $VERSION = '0.0011'; # VERSION
+our $VERSION = '0.0014'; # VERSION
 
 use Chart::GGPlot::Util qw(collect_functions_from_package);
 
@@ -19,6 +19,7 @@ our @sub_namespaces = qw(
   Polygon
   Rect Tile Raster
   Smooth
+  Text
 );
 
 for my $name (@sub_namespaces) {
@@ -51,7 +52,7 @@ Chart::GGPlot::Geom::Functions - Function interface for Chart::GGPlot::Geom
 
 =head1 VERSION
 
-version 0.0011
+version 0.0014
 
 =head1 DESCRIPTION
 
@@ -913,6 +914,85 @@ They may also be parameters to the paired geom/stat.
 
 See also L<Chart::GGPlot::Stat::Functions/stat_smooth>.
 
+=head2 geom_text
+
+    geom_text(:$mapping=undef, :$data=undef, :$stat='identity',
+              :$position='identity',
+              :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
+              %rest)
+
+C<geom_text()> adds text to the plot.
+
+Arguments:
+
+=over 4
+
+=item * $mapping
+
+Set of aesthetic mappings created by C<aes()>. If specified and
+C<$inherit_aes> is true (the default), it is combined with the default
+mapping at the top level of the plot.
+You must supply mapping if there is no plot mapping.
+
+=item * $data
+
+The data to be displayed in this layer.
+If C<undef>, the default, the data is inherited from the plot data as
+specified in the call to C<ggplot()>.
+
+=item * $stat
+
+The statistical transformation to use on the data for this layer, as a
+string.
+
+=item * $position
+
+Position adjustment, either as a string, or the result of a call to a
+position adjustment function.
+
+=item * $na_rm
+
+If false, the default, missing values are removed with a warning.
+If true, missing values are silently removed.
+
+=item * $show_legend
+
+Should this layer be included in the legends?
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
+
+=item * $inherit_aes
+
+If false, overrides the default aesthetics, rather than combining with them.
+This is most useful for helper functions that define both data and
+aesthetics and shouldn't inherit behaviour from the default plot
+specification.
+
+=item * %rest
+
+Other arguments passed to C<Chart::GGPlot::Layer-E<gt>new()>.
+These are often aesthetics, used to set an aesthetic to a fixed value,
+like C<color =E<gt> "red", size =E<gt> 3>.
+They may also be parameters to the paired geom/stat.
+
+=item * $hjust, $vjust
+
+You can modify text alignment with the C<hjust> and C<vjust> aesthetics.
+These can either be a number between 0 (right/bottom) and 1 (top/left) or a
+string, (C<"left">, C<"right">, C<"bottom">, C<"top">,
+C<"center">/C<"middle">).
+
+=item * $family
+
+Font family. Default is C<"sans">.
+
+=item * $size
+
+Font size in mm. Default is 3.88 mm (11pt).
+
+=back
+
 =head1 SEE ALSO
 
 L<Chart::GGPlot::Layer>,
@@ -924,7 +1004,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019-2020 by Stephan Loyd.
+This software is copyright (c) 2019-2021 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
