@@ -7,7 +7,7 @@ package Chart::GGPlot::Util::Scales;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0011'; # VERSION
+our $VERSION = '0.0014'; # VERSION
 
 use Color::Brewer;
 use Color::Library;
@@ -16,9 +16,8 @@ use Data::Munge qw(elem);
 use Machine::Epsilon qw(machine_epsilon);
 use Math::Gradient qw(multi_array_gradient);
 use Math::Round qw(round);
-use Math::Interpolate;
 use Memoize;
-use PDL::Primitive qw(which);
+use PDL::Primitive qw(which interpol);
 use Number::Format 1.75;
 use Scalar::Util qw(looks_like_number);
 use Time::Moment;
@@ -221,15 +220,14 @@ fun _color_ramp ($colors) {
             no warnings 'numeric';
             map { $gradient[$_] } ( $p * ( @gradient - 1 ) )->rint->flatten;
         };
-        
         my $rslt = PDL::SV->new( \@mapped );
         $rslt = $rslt->setbadif( $p->isbad ) if $p->badflag;
         return $rslt;
     };
 }
 
-# Arbitrary colour gradient palette (continous).
-fun gradient_n_pal ( $colors, $values = PDL->null ) {
+# Arbitrary color gradient palette (continous).
+fun gradient_n_pal ( $colors, $values = [] ) {
     my $ramp = _color_ramp($colors);
 
     my $length = $values->length;
@@ -238,12 +236,8 @@ fun gradient_n_pal ( $colors, $values = PDL->null ) {
     return fun($p) {
         return PDL->null if ( $p->isempty );
 
-        if ($xs) {
-            my $p_adjusted = pdl(
-                map {
-                    Math::Interpolate::robust_interpolate( $_, $values, \$xs )
-                } @{ $p->unpdl }
-            );
+        if (defined $xs) {
+            my $p_adjusted = interpol($p, pdl($values), $xs);
             return $ramp->($p_adjusted);
         }
         else {
@@ -946,7 +940,7 @@ Chart::GGPlot::Util::Scales - R 'scales' package functions used by Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0011
+version 0.0014
 
 =head1 FUNCTIONS
 
@@ -1019,7 +1013,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019-2020 by Stephan Loyd.
+This software is copyright (c) 2019-2021 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
